@@ -208,7 +208,7 @@ class ProgressesViewTest(TestCase):
         self.assertEqual(response.status_code, 200)
 
     def test_context_variables(self):
-        '''The progress() view supplies the context variables "course", "session", "current_class", "assignments", and "students". If a CSV file is requested, the template "autodidact/students.csv" is used.'''
+        '''The progresses() view supplies the context variables "course", "session", "current_class", "assignments", and "students".'''
 
         c = Client()
         c.login(username='teacher', password=password)
@@ -220,15 +220,6 @@ class ProgressesViewTest(TestCase):
         self.assertQuerysetEqual(response.context['students'], map(repr, self.klass.students.all()), ordered=False)
         self.assertQuerysetEqual(response.context['assignments'], map(repr, self.session.assignments.all()))
 
-        response = c.get(url, {'days': 1, 'filetype': 'csv'})
-        self.assertTemplateUsed(response, 'autodidact/students.csv')
-        with self.assertRaises(KeyError):
-            response.context['course']
-            response.context['session']
-            response.context['current_class']
-            response.context['assignments']
-        self.assertQuerysetEqual(response.context['students'], map(repr, self.klass.students.all()), ordered=False)
-
 class AssignmentViewTest(TestCase):
     def setUp(self):
         self.teacher = get_user_model()(username='teacher', is_staff=True)
@@ -253,33 +244,12 @@ class AssignmentViewTest(TestCase):
         self.klass.students.add(self.student)
         self.klass.save()
 
-    def test_get_parameter(self):
-        '''The GET parameter "step", if present, must be valid. If the requested step doesn't exist, a 404 is returned.'''
-
-        c = Client()
-        c.login(username='student', password=password)
-        url = reverse('assignment', args=[course_slug, '1', '1'])
-        response = c.get(url)
-        self.assertEqual(response.status_code, 404)
-        self.assignment.active = True
-        self.assignment.save()
-        response = c.get(url)
-        self.assertEqual(response.status_code, 200)
-        response = c.get(url, {'step': 'haha'})
-        self.assertEqual(response.status_code, 400)
-        response = c.get(url, {'step': -1})
-        self.assertEqual(response.status_code, 400)
-        response = c.get(url, {'step': 4})
-        self.assertEqual(response.status_code, 404)
-        response = c.get(url, {'step': 1})
-        self.assertEqual(response.status_code, 200)
-
     def test_context_variables(self):
         '''The assignment() view supplies the context variables "course", "session", "assignment", "step", "first", "last", and "count"'''
 
         c = Client()
         c.login(username='student', password=password)
-        url = reverse('assignment', args=[course_slug, '1', '1'])
+        url = reverse('assignment', args=[course_slug, '1', '1']) + '?step=1'
         self.assignment.active = True
         self.assignment.save()
         response = c.get(url)
@@ -287,9 +257,6 @@ class AssignmentViewTest(TestCase):
         self.assertEqual(response.context['session'], self.session)
         self.assertEqual(response.context['assignment'], self.assignment)
         self.assertEqual(response.context['step'], self.step1)
-        self.assertEqual(response.context['first'], True)
-        self.assertEqual(response.context['last'], False)
-        self.assertEqual(response.context['count'], 3)
 
     def test_post_answer(self):
         '''When an answer is submitted in a POST request, a CompletedStep object is created or updated'''
@@ -298,17 +265,17 @@ class AssignmentViewTest(TestCase):
         answer2 = '𝑝 < 0.05'
         c = Client()
         c.login(username='student', password=password)
-        url = reverse('assignment', args=[course_slug, '1', '1'])
+        url = reverse('assignment', args=[course_slug, '1', '1']) + '?step=1'
         self.assignment.active = True
         self.assignment.save()
         response = c.post(url, {'answer': answer1})
         self.assertEqual(response.status_code, 302)
         response = c.get(url)
-        self.assertEqual(response.context['completedstep'].answer, answer1)
+        self.assertEqual(response.context['step'].completedstep.answer, answer1)
         response = c.post(url, {'answer': answer2})
         self.assertEqual(response.status_code, 302)
         response = c.get(url)
-        self.assertEqual(response.context['completedstep'].answer, answer2)
+        self.assertEqual(response.context['step'].completedstep.answer, answer2)
 
 class StartclassViewTest(TestCase):
     def setUp(self):
@@ -326,7 +293,6 @@ class StartclassViewTest(TestCase):
         c.login(username='teacher', password=password)
         url = reverse('startclass')
         self.assertEqual(c.get(url).status_code, 405)
-        self.assertEqual(c.post(url).status_code, 400)
         self.assertEqual(c.post(url, {'class_nr': 'testclassnumbertoolong'}).status_code, 400)
         self.assertEqual(c.post(url, {'class_nr': 'testclass'}).status_code, 404)
         self.assertEqual(c.post(url, {'session': '348734', 'class_nr': 'testclass'}).status_code, 404)
